@@ -6,9 +6,11 @@ import yaml
 from flatten_dict import unflatten
 
 from ..config.mapping import config_map
+from ..core.settings import get_settings
 from ..experiment import ExperimentComponent
 from ..utils.dicts import update_dict
-from .parser import ModuleClass, parse_mixins
+from ..utils.importing import ModuleClass
+from .parser import parse_mixins
 
 
 def collect_updates(version):
@@ -25,6 +27,8 @@ def collect_updates(version):
 
 
 def mapped_config(config):
+    if isinstance(config, list):
+        return [mapped_config(c) for c in config]
     config["config"] = config["args"]
     return config_map(config)
 
@@ -36,13 +40,13 @@ class ConfigInterface:
             version = []
         self.version = version
         self.default_class = default_class
+        self.schema_validation = get_settings()["schema_validation"]
 
     def _get_version(self, name, config, current=None):
-        # from yaml string
-        if not name.startswith("~") and not (
-            name.startswith("_") and name.endswith("_")
-        ):
-            return yaml.load(name, Loader=yaml.FullLoader)
+        # from yaml file
+        if name.endswith(".yaml") or name.endswith(".json"):
+            with open(name) as f:
+                return yaml.load(f, Loader=yaml.FullLoader)
 
         # from mixin
         if name.startswith("_") and name.endswith("_"):
@@ -54,6 +58,10 @@ class ConfigInterface:
                     f"Did you register it under 'mixins'?\n"
                 )
 
+        # from yaml string
+        if not name.startswith("~"):
+            return yaml.load(name, Loader=yaml.FullLoader)
+
         # from local version
         if name in config:
             version = copy.deepcopy(config[name])
@@ -99,7 +107,7 @@ class ConfigInterface:
             elif key == "flags":
                 payload["flags"] = config_map(component["flags"])
             elif components is not None and key == "components":
-                payload["components"] = [mapped_config(c) for c in components]
+                payload["components"] = mapped_config(components)
             elif resources is not None and key == "resources":
                 payload["resources"] = resources
             else:
@@ -139,6 +147,20 @@ class ConfigInterface:
         config["flags"]["NAME"] = name
         config["flags"]["MODULE"] = config["module"]
 
+        # output redirection
+        if "OUTPUT_REDIRECTION" not in config["flags"]:
+            config["flags"]["OUTPUT_REDIRECTION"] = "SYS_AND_FILE"
+        if config["flags"]["OUTPUT_REDIRECTION"] not in (
+            "SYS_AND_FILE",
+            "DISABLED",
+            "FILE_ONLY",
+            "SYS_AND_FILE",
+            "DISCARD",
+        ):
+            raise ValueError(
+                f"Invalid OUTPUT_REDIRECTION mode: {config['flags']['OUTPUT_REDIRECTION']}"
+            )
+
         # carry over global evaluation config
         if "_evaluate" not in config["args"]:
             config["args"]["_evaluate"] = self.data["_evaluate"]
@@ -249,7 +271,9 @@ class ConfigInterface:
                 # merge with version
                 version = update_dict(version, k)
 
-        config["args"] = update_dict(config["args"], version, preserve_schema=True)
+        config["args"] = update_dict(
+            config["args"], version, preserve_schema=self.schema_validation
+        )
 
         # remove unused versions
         config["args"] = {
