@@ -3,7 +3,7 @@ import webbrowser
 import click
 import uvicorn
 
-from ..server.server import server
+from ..server.server import server as machinable_server
 
 
 @click.command()
@@ -11,7 +11,7 @@ from ..server.server import server
 @click.option("--port", default=5000, help="Port")
 @click.option("--log-level", default="info", help="Log level")
 def server(host, port, log_level):
-    uvicorn.run(server, host=host, port=port, log_level=log_level)
+    uvicorn.run(machinable_server, host=host, port=port, log_level=log_level)
 
 
 @click.command()
@@ -20,4 +20,4 @@ def app():
     webbrowser.open("http://app.machinable.org/", new=0, autoraise=True)
     # todo: find free port and encode the endpoint via ?get request or #
     # todo: secure endpoint with token request
-    uvicorn.run(server, host=host, port=5000, log_level="warning")
+    uvicorn.run(machinable_server, host=host, port=5000, log_level="warning")
