@@ -3,25 +3,26 @@ import inspect
 import os
 import re
 from collections import OrderedDict
-from inspect import getattr_static
 from typing import Dict, List, Optional, Union
 
 import pendulum
 
 from ..config.mapping import ConfigMap, ConfigMethod, config_map
-from ..config.parser import ModuleClass, parse_mixins
+from ..config.parser import parse_mixins
 from ..registration import Registration
-from ..store import Store
-from ..store.log import Log
-from ..store.record import Record
+from ..storage import Storage
+from ..storage.log import Log
+from ..storage.record import Record
 from ..utils.dicts import update_dict
 from ..utils.formatting import exception_to_str
 from ..utils.host import get_host_info
+from ..utils.importing import ModuleClass
 from ..utils.system import OutputRedirection, set_process_title
 from ..utils.traits import Jsonable
 from ..utils.utils import apply_seed
 from .events import Events
 from .exceptions import ExecutionException
+from .mixin import Mixin, MixinInstance
 
 
 def set_alias(obj, alias, value):
@@ -124,10 +125,10 @@ class ComponentState(Jsonable):
     def __init__(
         self, created=False, executed=False, destroyed=False, checkpoints=None
     ):
+        self.created = created
+        self.executed = executed
+        self.destroyed = destroyed
         self.checkpoints = checkpoints or []
-        self.created = False
-        self.executed = False
-        self.destroyed = False
 
     def serialize(self):
         return {
@@ -143,9 +144,9 @@ class ComponentState(Jsonable):
 
     @staticmethod
     def save(component):
-        if component.node is not None or component.store is None:
+        if component.node is not None or component.storage is None:
             return False
-        component.store.write(
+        component.storage.save_file(
             "state.json",
             {
                 "component": component.component_state.serialize(),
@@ -156,61 +157,9 @@ class ComponentState(Jsonable):
                 else None,
             },
             overwrite=True,
-            _meta=True,
         )
 
 
-class MixinInstance:
-    def __init__(self, controller, mixin_class, attribute):
-        self.config = {
-            "controller": controller,
-            "class": mixin_class,
-            "attribute": attribute,
-        }
-
-    def __getattr__(self, item):
-        # lazy-load class
-        if isinstance(self.config["class"], ModuleClass):
-            self.config["class"] = self.config["class"].load(instantiate=False)
-
-        attribute = getattr(self.config["class"], item, None)
-
-        if attribute is None:
-            raise AttributeError(
-                f"Mixin '{self.config['class'].__name__}' has no method '{item}'"
-            )
-
-        if isinstance(attribute, property):
-            return attribute.fget(self.config["controller"])
-
-        if not callable(attribute):
-            return attribute
-
-        if isinstance(getattr_static(self.config["class"], item), staticmethod):
-            return attribute
-
-        # if attribute is non-static method we decorate it to pass in the controller
-
-        def bound_method(*args, **kwargs):
-            # bind mixin instance to controller for mixin self reference
-            self.config["controller"].__mixin__ = getattr(
-                self.config["controller"], self.config["attribute"]
-            )
-            output = attribute(self.config["controller"], *args, **kwargs)
-
-            return output
-
-        return bound_method
-
-
-class Mixin:
-    """
-    Mixin base class. All machinable mixins must inherit from this base class.
-    """
-
-    pass
-
-
 class Component(Mixin):
     """
     Component base class. All machinable components must inherit from this class.
@@ -235,10 +184,9 @@ class Component(Mixin):
 
         self._node: Optional[Component] = node
         self._components: Optional[List[Component]] = None
-        self._store: Optional[Store] = None
-        self._events = Events()
+        self._storage: Optional[Storage] = None
+        self._events: Events = Events()
         self._actor_config = None
-        self._storage_config = None
         self.__mixin__ = None
         self.component_status = dict()
         self.component_state = ComponentState()
@@ -272,7 +220,7 @@ class Component(Mixin):
         self.on_after_init()
 
     def bind(self, mixin, attribute):
-        """Binds a mixin to the components
+        """Binds a mixin to the component
 
         # Arguments
         mixin: Mixin module or class
@@ -280,7 +228,7 @@ class Component(Mixin):
         """
         if isinstance(mixin, str):
             mixin = ModuleClass(mixin.replace("+.", "vendor."), baseclass=Mixin)
-            setattr(self, attribute, MixinInstance(self, mixin, attribute))
+        setattr(self, attribute, MixinInstance(self, mixin, attribute))
 
     @property
     def config(self) -> ConfigMap:
@@ -311,34 +259,40 @@ class Component(Mixin):
         self._components = value
 
     @property
-    def store(self) -> Store:
-        if self._store is None and isinstance(self.node, Component):
+    def storage(self) -> Storage:
+        """Storage interface"""
+        if self._storage is None and isinstance(self.node, Component):
             # forward to node store if available
-            return self.node.store
-        return self._store
+            return self.node.storage
+        return self._storage
 
-    @store.setter
-    def store(self, value):
-        self._store = value
+    @storage.setter
+    def storage(self, value):
+        self._storage = value
 
     @property
     def record(self) -> Record:
         """Record writer instance"""
-        return self.store.record
+        return self.storage.get_records(
+            "default",
+            events=self.events,
+            created_at=self.component_status["started_at"],
+        )
 
     @property
     def log(self) -> Log:
         """Log writer instance"""
-        return self.store.log
+        return self.storage.log
 
     @property
     def events(self) -> Events:
+        """Event interface"""
         return self._events
 
     def __getattr__(self, name):
         # Mixins and dynamic attributes are set during construction; this helps suppressing IDE warnings
         raise AttributeError(
-            f"{self.__class__.__name__} components has not attribute {name}"
+            f"{self.__class__.__name__} component has not attribute {name}"
         )
 
     def dispatch(
@@ -357,34 +311,32 @@ class Component(Mixin):
 
             self.on_init_storage(storage_config)
 
-            self._storage_config = storage_config
-            self.store = Store(component=self, config=storage_config)
-
-            if not storage_config["url"].startswith("mem://"):
-                OutputRedirection.apply(
-                    self._storage_config["output_redirection"],
-                    self.store.get_stream,
-                    "output.log",
-                )
-
-            if not self.store.exists("host.json", _meta=True):
-                self.store.write("host.json", get_host_info(), _meta=True)
-            if not self.store.exists("component.json", _meta=True):
-                self.store.write("component.json", self.serialize(), _meta=True)
-            if not self.store.exists("components.json", _meta=True):
-                self.store.write(
-                    "components.json",
-                    [component.serialize() for component in self.components]
-                    if self.components
-                    else [],
-                    _meta=True,
-                )
-            self.component_state.save(self)
+            self.storage = Storage.create(storage_config)
 
             self.component_status["started_at"] = str(pendulum.now())
             self.component_status["finished_at"] = False
             self.refresh_status(log_errors=True)
 
+            if not storage_config["url"].startswith("mem://"):
+                OutputRedirection.apply(
+                    self.flags["OUTPUT_REDIRECTION"],
+                    self.storage.get_stream,
+                    "output.log",
+                )
+
+            if not self.storage.has_file("host.json"):
+                self.storage.save_file("host.json", get_host_info())
+            if not self.storage.has_file("component.json"):
+                self.storage.save_file("component.json", self.serialize())
+            if not self.storage.has_file("components.json"):
+                self.storage.save_file(
+                    "components.json",
+                    [component.serialize() for component in self.components]
+                    if self.components
+                    else [],
+                )
+            self.component_state.save(self)
+
             if self.node is None:
                 self.events.heartbeats(seconds=self.flags.get("HEARTBEAT", 15))
                 self.events.on("heartbeat", self.refresh_status)
@@ -489,15 +441,7 @@ class Component(Mixin):
 
                 try:
                     callback = self.on_execute_iteration(iteration)
-                    if self.on_after_execute_iteration(iteration) is not False:
-                        # trigger records.save() automatically
-                        if (
-                            self.store
-                            and self.store.has_records()
-                            and not self.store.record.empty()
-                        ):
-                            self.store.record["_iteration"] = iteration
-                            self.store.record.save()
+                    self.on_after_execute_iteration(iteration)
                 except (KeyboardInterrupt, StopIteration):
                     callback = StopIteration
 
@@ -550,9 +494,7 @@ class Component(Mixin):
         """
         try:
             self.component_status["heartbeat_at"] = str(pendulum.now())
-            self.store.write(
-                "status.json", self.component_status, overwrite=True, _meta=True
-            )
+            self.storage.save_file("status.json", self.component_status)
         except (IOError, Exception) as ex:
             if log_errors:
                 self.log.error(
@@ -563,29 +505,6 @@ class Component(Mixin):
 
         return True
 
-    def get_url(self, append=""):
-        """Returns the storage URL of the component"""
-        return os.path.join(
-            self._storage_config["url"],
-            os.path.join(
-                self._storage_config.get("directory", ""),
-                self._storage_config["experiment"],
-                self._storage_config.get("component", ""),
-                append,
-            ),
-        )
-
-    def local_directory(self, append=""):
-        """Returns the local storage filesystem path, or False if non-local
-
-        # Returns
-        Local filesystem path, or False if non-local
-        """
-        if not self._storage_config["url"].startswith("osfs://"):
-            return False
-
-        return os.path.join(self.get_url().split("osfs://")[-1], append)
-
     def set_seed(self, seed=None) -> bool:
         """Applies a global random seed
 
@@ -614,16 +533,16 @@ class Component(Mixin):
             timestep: int = len(self.component_state.checkpoints)
 
         if path is None:
-            if not self.store:
+            if not self.storage:
                 raise ValueError("You need to specify a checkpoint path")
 
-            fs_prefix, basepath = self.store.config["url"].split("://")
+            fs_prefix, basepath = self.storage.config["url"].split("://")
             if fs_prefix != "osfs":
                 # todo: support non-local filesystems via automatic sync
                 raise NotImplementedError(
                     "Checkpointing to non-os file systems is currently not supported."
                 )
-            checkpoint_path = self.store.get_path("checkpoints", create=True)
+            checkpoint_path = self.storage.get_path("checkpoints", create=True)
             path = os.path.join(os.path.expanduser(basepath), checkpoint_path)
 
         checkpoint = self.on_save(path, timestep)
@@ -641,8 +560,8 @@ class Component(Mixin):
         # Arguments
         filepath: Checkpoint filepath
         """
-        if self.store is not None:
-            self.store.log.info(f"Restoring checkpoint `{checkpoint}`")
+        if self.storage is not None:
+            self.log.info(f"Restoring checkpoint `{checkpoint}`")
         return self.on_restore(checkpoint)
 
     def serialize(self):
@@ -802,13 +721,8 @@ class Component(Mixin):
 
         flags = getattr(self, "flags", {})
         r = f"Component <{flags.get('EXPERIMENT_ID', '-')}:{flags.get('UID', '-')}>"
-        if self._storage_config is not None:
-            url = os.path.join(
-                self._storage_config.get("directory", ""),
-                self._storage_config.get("experiment", ""),
-                self._storage_config.get("component", ""),
-            )
-            r += f" ({url})"
+        if self.storage is not None:
+            r += f" ({self.storage.get_url()})"
         return r
 
     def __str__(self):
@@ -861,26 +775,24 @@ class FunctionalComponent:
                 payload["components"] = [
                     config_map(component) for component in components
                 ]
-            elif key == "store" or key == "_store":
-                if key == "_store":
-                    payload["store"] = storage_config
+            elif key == "storage" or key == "_storage":
+                if key == "_storage":
+                    payload["storage"] = storage_config
                 else:
-                    store = Store(component=self, config=storage_config)
-                    store.write("host.json", get_host_info(), _meta=True)
-                    store.write(
-                        "component",
+                    storage = Storage.create(storage_config)
+                    storage.save_file("host.json", get_host_info())
+                    storage.save_file(
+                        "component.json",
                         {"config": self.node["config"], "flags": self.node["flags"]},
-                        _meta=True,
                     )
-                    store.write(
-                        "components",
+                    storage.save_file(
+                        "components.json",
                         [
                             {"config": c["config"], "flags": c["flags"]}
                             for c in components
                         ],
-                        _meta=True,
                     )
-                    payload["store"] = store
+                    payload["storage"] = storage
             else:
                 raise ValueError(
                     f"Unrecognized argument: '{key}'. "
