@@ -6,7 +6,7 @@ import pendulum
 import sh
 
 from ..core.exceptions import ExecutionException
-from ..filesystem import open_fs
+from ..filesystem import open_fs, abspath
 from ..utils.formatting import exception_to_str
 from .engine import Engine
 
@@ -63,12 +63,12 @@ class SlurmEngine(Engine):
     def _submit(self, execution):
         url = os.path.join(
             execution.storage.config["url"],
-            execution.storage.config.get("directory", ""),
+            execution.storage.config["directory"] or "",
             execution.experiment_id,
         )
 
         # script path
-        script_path = "_engine/slurm_" + pendulum.now().strftime("%d-%m-%Y_%H-%M-%S")
+        script_path = "engine/slurm_" + pendulum.now().strftime("%d-%m-%Y_%H-%M-%S")
         with open_fs(url) as filesystem:
             filesystem.makedirs(script_path, recreate=True)
         script_url = os.path.join(url, script_path)
@@ -77,7 +77,7 @@ class SlurmEngine(Engine):
         project = json.dumps(execution.project.options).replace('"', '\\"')
         code = f"""
         import machinable as ml
-        e = ml.Execution.from_storage('{url}')
+        e = ml.Execution.from_storage('{abspath(url)}')
         e.set_engine('native')
         e.set_storage({execution.storage.config})
         e.set_project(ml.Project.from_json('{project}'))
@@ -103,9 +103,12 @@ class SlurmEngine(Engine):
             kwargs,
         ) in execution.schedule.iterate(execution.storage.config):
             component_id = component["flags"]["COMPONENT_ID"]
+            component_path = os.path.join(url.replace("osfs://", ""), component_id)
+            os.makedirs(component_path, exist_ok=True)
             script = f"{self.script}\n"
             script += f'#SBATCH --job-name="{execution.experiment_id}:{component_id}"\n'
-            script += f"#SBATCH -o {os.path.join(url.replace('osfs://', ''), component_id,  'output.log')}\n"
+            script += f"#SBATCH -o {os.path.join(component_path,  'output.log')}\n"
+            script += "#SBATCH --open-mode=append\n"
             script += f"export MACHINABLE_PROJECT={execution.project.directory_path}\n"
             try:
                 script += self.commands["before_script"] + ";\n"
@@ -125,38 +128,33 @@ class SlurmEngine(Engine):
             )
 
             if target.find("://") != -1:
-                raise ValueError("Slurm engine only support local storages")
+                raise ValueError("Slurm engine only supports local storages")
 
             with open(target, "w") as f:
                 f.write(script)
             st = os.stat(target)
             os.chmod(target, st.st_mode | stat.S_IEXEC)
 
-            # parse resource arguments
-            if resources is None:
-                resources = {}
-            elif isinstance(resources, str):
-                resources = {"args", [resources]}
-            elif isinstance(resources, (tuple, list)):
-                resources = {"args": list(resources)}
-
-            arguments = resources.get("args", [])
-            if isinstance(arguments, str):
-                arguments = [arguments]
-
-            command = []
-            for a in arguments:
-                if a.startswith("--"):
-                    command.append(a)
-                    continue
-                if a.startswith("-"):
-                    command.extend(a.split(" ", maxsplit=1))
-            command.append(target)
-
             # submit to slurm
             try:
-                p = sh.sbatch(*command)
-                execution.set_result(p, echo=False)
+                sbatch_arguments = []
+                for k, v in self.canonicalize_resources(resources).items():
+                    sbatch_arguments.append(k)
+                    if v not in [None, True]:
+                        sbatch_arguments.append(v)
+                sbatch_arguments.append(target)
+                p = sh.sbatch(*sbatch_arguments)
+                output = p.stdout.decode("utf-8")
+                try:
+                    job_id = int(output.rsplit(" ", maxsplit=1)[-1])
+                except ValueError:
+                    job_id = False
+                info = self.serialize()
+                info.update(
+                    {"job_id": job_id, "cmd": "sbatch " + " ".join(sbatch_arguments),}
+                )
+                execution.set_result(info, echo=False)
+                execution.storage.save_file(f"{component_id}/engine/info.json", info)
             except Exception as ex:
                 if isinstance(ex, sh.ErrorReturnCode):
                     message = ex.stderr.decode("utf-8")
@@ -172,14 +170,88 @@ class SlurmEngine(Engine):
 
         return execution
 
-    def storage_middleware(self, storage):
-        if storage.get("url", "mem://").startswith("mem://"):
+    def on_before_storage_creation(self, execution):
+        if execution.storage.config.get("url", "mem://").startswith("mem://"):
             raise ValueError("Remote engine does not support temporary file systems")
 
-        storage["allow_overwrites"] = True
-        storage["output_redirection"] = "DISABLED"  # use slurm log instead
+        # disable output redirection and rely on Slurm output log instead
+        def disable_output_redirection(i, component, element):
+            element[1]["flags"]["OUTPUT_REDIRECTION"] = "DISABLED"
+            return element
 
-        return storage
+        execution.schedule.transform(disable_output_redirection)
+
+    def canonicalize_resources(self, resources):
+        if resources is None:
+            return {}
+
+        shorthands = {
+            "A": "account",
+            "B": "extra-node-info",
+            "C": "constraint",
+            "c": "cpus-per-task",
+            "d": "dependency",
+            "D": "workdir",
+            "e": "error",
+            "F": "nodefile",
+            "H": "hold",
+            "h": "help",
+            "I": "immediate",
+            "i": "input",
+            "J": "job-name",
+            "k": "no-kill",
+            "L": "licenses",
+            "M": "clusters",
+            "m": "distribution",
+            "N": "nodes",
+            "n": "ntasks",
+            "O": "overcommit",
+            "o": "output",
+            "p": "partition",
+            "Q": "quiet",
+            "s": "share",
+            "t": "time",
+            "u": "usage",
+            "V": "version",
+            "v": "verbose",
+            "w": "nodelist",
+            "x": "exclude",
+            "g": "geometry",
+            "R": "no-rotate",
+        }
+
+        canonicalized = {}
+        for k, v in resources.items():
+            prefix = ""
+            if k.startswith("-/"):
+                prefix = "-/"
+                k = k[2:]
+
+            if k.startswith("--"):
+                # already correct
+                canonicalized[prefix + k] = v
+                continue
+            if k.startswith("-"):
+                # -p => --partition
+                try:
+                    if len(k) != 2:
+                        raise KeyError("Invalid length")
+                    canonicalized[prefix + "--" + shorthands[k[1]]] = v
+                    continue
+                except KeyError:
+                    raise ValueError(f"Invalid short option: {k}")
+            if len(k) == 1:
+                # p => --partition
+                try:
+                    canonicalized[prefix + "--" + shorthands[k]] = v
+                    continue
+                except KeyError:
+                    raise ValueError(f"Invalid short option: -{k}")
+            else:
+                # option => --option
+                canonicalized[prefix + "--" + k] = v
+
+        return canonicalized
 
     def __repr__(self):
         return f"Engine <slurm>"
