@@ -23,7 +23,7 @@ from ..project.export import Export
 from ..registration import Registration
 from ..storage import Storage
 from ..storage.experiment import StorageExperiment
-from ..utils.dicts import update_dict
+from ..utils.dicts import merge_dict, update_dict
 from ..utils.formatting import exception_to_str, msg
 from ..utils.host import get_host_info
 from ..utils.identifiers import (
@@ -208,23 +208,34 @@ class Execution(Jsonable):
                         color="header",
                     )
                     resources = None
-            elif callable(resources):
-                resources = resources(
+            else:
+                if callable(resources):
+                    resources = resources(
+                        engine=self.engine,
+                        component=mapped_config(component_config),
+                        components=mapped_config(components_config),
+                    )
+
+                default_resources = Registration.get().default_resources(
                     engine=self.engine,
                     component=mapped_config(component_config),
-                    components=[
-                        mapped_config(component) for component in components_config
-                    ],
-                )
-            elif resources is None:
-                resources = Registration.get().default_resources(
-                    engine=self.engine,
-                    component=mapped_config(component_config),
-                    components=[
-                        mapped_config(component) for component in components_config
-                    ],
+                    components=mapped_config(components_config),
                 )
 
+                if resources is None and default_resources is not None:
+                    # use default resources
+                    resources = default_resources
+                elif resources is not None and default_resources is not None:
+                    # merge with default resources
+                    if resources.pop("_inherit_defaults", True) is not False:
+                        canonicalize_resources = getattr(
+                            self.engine, "canonicalize_resources", lambda x: x
+                        )
+                        resources = merge_dict(
+                            canonicalize_resources(default_resources),
+                            canonicalize_resources(resources),
+                        )
+
             if "tune" in self.experiment.specification:
                 self.schedule.add_tune(
                     component=component_config,
@@ -334,14 +345,11 @@ class Execution(Jsonable):
             with open_fs(self.storage.config["url"]) as filesystem:
                 experiment_id = filesystem.load_file("execution.json")["experiment_id"]
                 # register URL as parent storage and rewrite to experiments/ subdirectory
-                self.storage.config["ancestor"] = {
-                    "url": self.storage.config["url"],
-                    "experiment": experiment_id,
-                }
+                derived_from = self.storage.config["url"]
                 self.storage.config["url"] = os.path.join(
                     self.storage.config["url"], "experiments"
                 )
-                derived_from = self.storage.config["ancestor"]["url"]
+
         except (ValueError, KeyError, FileNotFoundError):
             pass
 
@@ -355,11 +363,15 @@ class Execution(Jsonable):
                 return element
 
             self.schedule.transform(set_derived_from_flag)
-            storage = self.engine.storage_middleware(self.storage.config)
 
             now = pendulum.now()
             self.timestamp = now.timestamp()
             self.started_at = str(now)
+
+            # allow engine and registration to make changes before storage submission
+            self.engine.on_before_storage_creation(self)
+            Registration.get().on_before_storage_creation(self)
+
             # do not backup on mem:// filesystem unless explicitly set to True
             code_backup = self.code_backup
             if code_backup is None and not self.storage.config["url"].startswith(
@@ -368,11 +380,7 @@ class Execution(Jsonable):
                 code_backup = True
 
             # collect and write execution data
-            url = os.path.join(
-                storage.get("url", "mem://"),
-                storage.get("directory", ""),
-                storage["experiment"],
-            )
+            url = self.storage.get_url()
             data = {
                 "code.json": {
                     "resolvers": {
