@@ -41,6 +41,14 @@ class Registration:
         """
         pass
 
+    def on_before_storage_creation(self, execution):
+        """Event triggered right before the storage is created
+
+        # Arguments
+        execution: machinable.Execution object
+        """
+        pass
+
     def on_submit(self, execution, is_resubmission):
         """Event triggered during submission of an execution
 
@@ -63,7 +71,7 @@ class Registration:
         baseclass: The component baseclass (either Component or Mixin)
         default: Optional default component that will be used if import fails
         """
-        return None
+        pass
 
     def on_component_import(self, component_candidate, module, baseclass, default):
         """Event triggered during component import from a module
@@ -79,7 +87,7 @@ class Registration:
         baseclass: The component baseclass (either Component or Mixin)
         default: Optional default component that will be used if import fails
         """
-        return None
+        pass
 
     def default_resources(self, engine, component, components):
         """Allows to specify global default resources"""
