@@ -5,7 +5,7 @@ from starlette.responses import PlainTextResponse
 from ..filesystem import open_fs
 
 
-async def storage_resolver(request):
+async def filesystem_resolver(request):
     url = base64.urlsafe_b64decode(request.path_params["url"]).decode("utf-8")
     filename = request.path_params["filename"]
 
