@@ -4,6 +4,8 @@ import random
 import string
 from keyword import iskeyword
 
+sentinel = object()
+
 
 def get_file_hash(filepath):
     """Returns a hash value of a file
@@ -86,6 +88,10 @@ def is_valid_variable_name(name):
     return name.isidentifier() and not iskeyword(name)
 
 
+def is_valid_module_path(name):
+    return all(map(is_valid_variable_name, name.split(".")))
+
+
 def random_str(length, random_state=None):
     if random_state is None or isinstance(random_state, int):
         random_state = random.Random(random_state)
